package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````2!4``#0```!0D0````0`!30`(``'
M`"@`%@`5``8````T````-````#0```#@````X`````0````$`````P```!0!
M```4`0``%`$``!@````8````!`````$````!````````````````````"'X`
M``A^```%```````!``$```#,C0``S(T!`,R-`0!P`@``G!(```8```````$`
M`@```-2-``#4C0$`U(T!`/````#P````!@````0```!1Y71D````````````
M```````````````&````$````%+E=&3,C0``S(T!`,R-`0`T`@``-`(```0`
M```!````+VQI8B]L9"UM=7-L+6%R;6AF+G-O+C$`$0```$P````(````"```
M``&0$``E0`2`*(`0!:"&4(2``0``"R`$C3B`$D&*!`@(3````$T```!1````
M5@```%<```!>````7P```&``````````8@```&,`````````9````&4```!H
M```````````````!KS3H:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?'94
M/)0A_^0.V7%8'/JA;&#"Y3\LL@&+;T+ZUX?B1\8!6.^7>;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[16,)<Q_J9R;X*<""FH:GE"_VE<;H^#[20``````````
M````````````````#!`````````#``<```````"0`0```````P`1``$`````
M`````````!(````)```````````````1````[`$`````````````$0```(@!
M`````````````!(````0```````````````2````Q0$`````````````$@``
M`!@``````````````!(````?```````````````2````^0$`````````````
M$@```-$!`````````````!(````H```````````````@````'P,`````````
M````(0```$```````````````!(```!&```````````````2````30``````
M````````$@```.P"`````````````!(```#=`@`````````````2````5```
M````````````$@```#8"`````````````!(```!;```````````````2````
MO`(`````````````$@```&(``````````````!(```!J```````````````2
M````I0(`````````````$@```'(``````````````!(```![````````````
M```@````U@(`````````````$@```)<``````````````!(```"<````````
M```````2````"@(`````````````$0```,,"`````````````!(```!C`@``
M```````````2````HP``````````````$@```%4"`````````````!(```!C
M`P`````````````2````'@,`````````````$0```(<"`````````````!(`
M```+`P`````````````2````%0(`````````````$@```"`#````````````
M`!$```"J```````````````2`````P,`````````````$@```+,`````````
M`````!$```"6`0`````````````2````Q0``````````````(@```-0`````
M`````````"````#J```````````````2````S@(`````````````$@```',"
M`````````````!(```#O```````````````2````]0``````````````(```
M`+`"`````````````!(````/`0`````````````2````M@$`````````````
M$@```!0!`````````````!(```"5`@`````````````2````&@$`````````
M````$@```*4!`````````````!(````H`0`````````````2````.0$`````
M````````$@```#$"`````````````!(```!"`@`````````````2````/P$`
M````````````$@```'P"`````````````!(```#\`@`````````````2````
M3@$`````````````$@```/0"`````````````!(```!B`0`````````````2
M````+`(`````````````$@```&D!`````````````!(```!P`0``````````
M```2````'0,`````````````(0```($!`````````````!(```!C!```:*`!
M```````0`!(`&`,``/P2``!,`@``$@`)`.8!``"@/0``!````!(`"@"E`P``
MN"4``/@&```2``D`<P0``"`O``!8````$@`)`((#``#L'@``!````!(`"0`7
M!```#!````0````2``<`R`,``+`L``!P`@``$@`)`!T$```\D`$``````!``
M$@!+!```\!X``#0"```2``D```0``#R0`0``````$``2`),#```$)0``M```
M`!(`"0"R`P``W!P``%`````2``D`N@,``(0D``!H````$@`)`-X#```D.P``
M1`$``!(`"0#S`P``)"$``!P````2``D`#`0``&B@`0``````$``2`&X$``!H
MH`$``````!``$@!(`P``;!4``%@````2``D`*P0``$`A```,`0``$@`)`.D#
M```XD`$`!````!$`$0!$!```/)`!```````0`!$`!00``$@5````````$@`)
M`!0$``#4.@``4````!(`"0!1`P``["0``!@````2``D`;`,``)@=``!4`0``
M$@`)`%@$``!H/```.`$``!(`"0!B!```:*`!```````0`!(`-P0``$PB```X
M`@``$@`)``!O<&5N9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT
M9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP
M`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&-L;W-E9&ER`%])5$U?
M9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C:'(`<F5A
M9&QI;FL`7U]S=&%C:U]C:&M?9W5A<F0`7U]C>&%?9FEN86QI>F4`7U]R96=I
M<W1E<E]F<F%M95]I;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!R96%D`')M9&ER`%]?<W1A=%]T:6UE-C0`7U]E<G)N;U]L;V-A
M=&EO;@!M:V1I<@!?7VQS=&%T7W1I;64V-`!P=&AR96%D7V=E='-P96-I9FEC
M`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S
M>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?
M8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%]F
M:6YI`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`
M4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y
M;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A
M;&QO8P!F<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P
M<FEN=&8`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV
M:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UA<FUH9BYS;RXQ`%]S=&%R=%]C
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P871H`'!A<E]M
M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS7U!!
M4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!?7V)S
M<U]S=&%R=`!?7V5N9%]?`'-H85]I;FET`%]?8G-S7W-T87)T7U\`<&%R7V1I
M<FYA;64`<&%R7VEN:71?96YV`%]E9&%T80!P87)?9FEN9'!R;V<`<VAA7V9I
M;F%L`%]?8G-S7V5N9%]?`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R
M;#4O8V]R95]P97)L+T-/4D4`````S(T!`!<```#0C0$`%P```,"/`0`7````
MS(\!`!<```#8CP$`%P````"0`0`7````")`!`!<````,D`$`%P```!20`0`7
M````&)`!`!<````<D`$`%P```""0`0`7````))`!`!<````LD`$`%P```#"0
M`0`7````.)`!`!<```#$CP$`%00``,B/`0`5!0``T(\!`!4-``#4CP$`%1P`
M`-R/`0`5(```X(\!`!4J``#DCP$`%2T``.B/`0`5+P``[(\!`!4P``#PCP$`
M%34``/2/`0`5.@``^(\!`!4\``#\CP$`%4```-".`0`6`P``U(X!`!8&``#8
MC@$`%@<``-R.`0`6"```X(X!`!8)``#DC@$`%@H``.B.`0`6"P``[(X!`!8,
M``#PC@$`%@T``/2.`0`6#P``^(X!`!80``#\C@$`%A$```"/`0`6$@``!(\!
M`!83```(CP$`%A0```R/`0`6%0``$(\!`!86```4CP$`%A<``!B/`0`6&```
M'(\!`!89```@CP$`%AH``"2/`0`6&P``*(\!`!8=```LCP$`%AX``#"/`0`6
M'P``-(\!`!8A```XCP$`%B(``#R/`0`6(P``0(\!`!8D``!$CP$`%B4``$B/
M`0`6)P``3(\!`!8H``!0CP$`%BD``%2/`0`6*P``6(\!`!8L``!<CP$`%BX`
M`&"/`0`6+P``9(\!`!8P``!HCP$`%C$``&R/`0`6,@``<(\!`!8S``!TCP$`
M%C0``'B/`0`6-@``?(\!`!8W``"`CP$`%C@``(2/`0`6.0``B(\!`!8[``",
MCP$`%CT``)"/`0`6/@``E(\!`!8_``"8CP$`%D$``)R/`0`60@``H(\!`!9#
M``"DCP$`%D0``*B/`0`610``K(\!`!9&``"PCP$`%D<``+2/`0`62```N(\!
M`!9)``"\CP$`%DL```%`+>D!0+WH'O\OX03@+>4$X)_E#N"/X`CPON6<?@$`
M`,:/XA?*C.*<_KSE`,:/XA?*C.*4_KSE`,:/XA?*C.*,_KSE`,:/XA?*C.*$
M_KSE`,:/XA?*C.)\_KSE`,:/XA?*C.)T_KSE`,:/XA?*C.)L_KSE`,:/XA?*
MC.)D_KSE`,:/XA?*C.)<_KSE`,:/XA?*C.)4_KSE`,:/XA?*C.),_KSE`,:/
MXA?*C.)$_KSE`,:/XA?*C.(\_KSE`,:/XA?*C.(T_KSE`,:/XA?*C.(L_KSE
M`,:/XA?*C.(D_KSE`,:/XA?*C.(<_KSE`,:/XA?*C.(4_KSE`,:/XA?*C.(,
M_KSE`,:/XA?*C.($_KSE`,:/XA?*C.+\_;SE`,:/XA?*C.+T_;SE`,:/XA?*
MC.+L_;SE`,:/XA?*C.+D_;SE`,:/XA?*C.+<_;SE`,:/XA?*C.+4_;SE`,:/
MXA?*C.+,_;SE`,:/XA?*C.+$_;SE`,:/XA?*C.*\_;SE`,:/XA?*C.*T_;SE
M`,:/XA?*C.*L_;SE`,:/XA?*C.*D_;SE`,:/XA?*C.*<_;SE`,:/XA?*C.*4
M_;SE`,:/XA?*C.*,_;SE`,:/XA?*C.*$_;SE`,:/XA?*C.)\_;SE`,:/XA?*
MC.)T_;SE`,:/XA?*C.)L_;SE`,:/XA?*C.)D_;SE`,:/XA?*C.)<_;SE`,:/
MXA?*C.)4_;SE`,:/XA?*C.),_;SE`,:/XA?*C.)$_;SE`,:/XA?*C.(\_;SE
M`,:/XA?*C.(T_;SE`,:/XA?*C.(L_;SE`,:/XA?*C.(D_;SE`,:/XA?*C.(<
M_;SE`,:/XA?*C.(4_;SE`,:/XA?*C.(,_;SE`,:/XA?*C.($_;SE`,:/XA?*
MC.+\_+SE`,:/XA?*C.+T_+SE`,:/XA?*C.+L_+SE`,:/XA?*C.+D_+SE`,:/
MXA?*C.+<_+SE`,:/XA?*C.+4_+SE`,:/XA?*C.+,_+SE`,:/XA?*C.+$_+SE
M,$`MZ1S03>(4`(WE$!"-Y0P@C>40$(WB#""-XA0`C>+@09_EJO__Z]PQG^4$
M0(_@`R"4Y]0QG^4"$*#A`P"4YV'__^O(,9_E`S"4YP!0T^7`,9_E``!5XP-`
ME.<+```:??__Z[`AG^4``%#C`B"/X`P`@N4!```:`0"@XYW__^NN___K``"4
MY<?__^M[5\#E``"4Y<3__^O.,]#E`C"#X\XSP.4``)3EO___Z\XST.4!,(/C
MSC/`Y10`G>4#((#B!`"`X@<!<.,```":=___ZP`!H.$(((WEDO__ZSP1G^40
MP)WE`1"/X`0`@>4`$)SE`#"@X0`0@.4D$9_E"""=Y0$0C^`$$(#E&!&?Y1#@
M@^(!$(_@`!"1Y0@0@.4($9_E`1"/X`P0@.4!$*#C%`"=Y0$`4.$O``#*``!0
MXP,0@.(0$*#3`1&@P0``H./<4)_E`0"#Y]@0G^4``(WE!5"/X`P`E>4!$(_@
M+/__ZP!`4.("```:#`"5Y63__^L`0*#AL%"?Y050C^`,`)7E0?__ZZ0`G^4`
M`(_@T```ZP``4.,,```:"#"5Y0``4^,#```:B`"?Y0``C^#(``#K"`"%Y7PP
MG^4#,(_@"`"3Y0``4.,````*D@8`ZV@PG^4#,(_@#`"3Y7G__^O3_O_K!`"@
MX1S0C>(P@+WH`4&<YP$0@>($0([DR?__ZI1[`0`X`0``-`$```0!```8`0``
MZ'P!`'!\`0#)+```)'P!`*PL``#X>P$`Q`@``-![`0`Y*@``SBD``)![`0!X
M>P$``+"@XP#@H.,0$)_E`1"/X`T`H.$/P,#C#-"@X0```.MX>`$`!T`MZ3P@
MG^4\$)_E`B"/X`'`DN<`$*#C,#"?Y0,PDN<$$(WE*!"?Y0$@DN<`((WE`!"0
MY00@@.(,`*#A_/[_ZPS0C>($\)WD1'D!`/P````4`0``"`$``"P`G^4L,)_E
M``"/X`,PC^```%/A(#"?Y0,PC^`>_R\!&""?Y0(PD^<``%/C'O\O`1/_+^%H
M>@$`9'H!`.!X`0`0`0``.`"?Y3@PG^4``(_@`S"/X``P0^"C'Z#A0Q&!X"0P
MG^7!$+#A`S"/X![_+P$8()_E`C"3YP``4^,>_R\!$_\OX21Z`0`@>@$`D'@!
M`"P!``!H,)_E$$`MZ0,PC^``,-/E7$"?Y0``4^,$0(_@$("]&%`PG^4#,)3G
M``!3XP(```I$,)_E`P"?Y]'^_^O*___K.#"?Y0,PE.<``%/C`@``"BP`G^4`
M`(_@=?[_ZP$@H.,@,)_E`S"/X``@P^40@+WHU'D!`$QX`0`D`0``;'D!``P!
M``!09P``>'D!`#0PG^4T()_E`S"/X`(PD^<``%/C!P``"A!`+>D@$)_E(`"?
MY0$0C^```(_@M/[_ZQ!`O>BZ___JN?__ZM!W`0`H`0``,'D!`/!F``"<,)_E
M\$<MZ0!04.(#,(_@!4"@`2````J(()_E`C"3YP!`D^4``%3C&P``"@&0H.$%
M,*#A`V"@X0$@T^0``%+C/0!2$_K__QH$@*#A!6!&X`APH.$$H)CD``!:XPI`
MH`$-```*!B"@X040H.$*`*#A6O[_ZP``4./T__\:!C#:YST`4^/Q__\:!'!'
MX$=QH.$!8(;B`'")Y09`BN`$`*#A\(>]Z(!W`0`<`0``!T`MZ4P@G^5,,)_E
M`B"/X`,PDN<-$*#A`#"3Y00PC>4`,*#CRO__ZS`@G^4H,)_E`B"/X`,PDN<`
M()/E!#"=Y0(@,^``,*#C````"JW^_^L,T(WB!/"=Y-1V`0`@`0``L'8!`'-`
M+>F0()_ED#"?Y0(@C^`#,)+G`$"@X0`PD^4$,(WE`#"@XPU0H.%T8)_E!F"/
MX`40H.$$`*#AK/__ZP``4.,)```:7""?Y5`PG^4"((_@`S"2YP`@D^4$,)WE
M`B`SX``PH.,*```*C?[_ZS@PG^4`()WE`S"6YP`PD^4",8/@!""3Y0``4N,$
M((/D^___&N;__^H(T(WB<("]Z'!V`0`@`0``4'8!`#!V`0`<`0``\$<MZ4`A
MG^5`,9_E`B"/X`,PDN>@T$WB`%!0X@`PD^6<,(WE`#"@XQ,```H`,-7E``!3
MXQ````J__?_K`&!0X@T```H(<9_E"(&?Y0B1G^4'<(_@"("/X`F0C^`&`*#A
MV?W_ZP!`4.(-```:!@"@X?#]_^L%`*#A-O[_Z]P@G^7(,)_E`B"/X`,PDN<`
M()/EG#"=Y0(@,^``,*#C*```"E/^_^L30(3B!Q"@X00`H.'"_?_K``!0X^?_
M_PH($*#A!`"@X;W]_^L``%#CXO__"@4`H.%#_O_K`*"@X00`H.%`_O_K``"*
MX`(`@.+%_?_K`*"@X00PH.$%(*#A"1"@X2_^_^L-$*#A"@"@X13^_^L!`'#C
M"@"@X0<```H0,)WE#SH#X@$)4^,#```:L___ZPH`H.$3_O_KQ___ZJ[]_^OZ
M___JH-"-XO"'O>C`=0$`(`$``/4D``#P)```[R0``$AU`0`00"WIB""?Y8@P
MG^4"((_@H-!-X@,PDN<-$*#A`$"@X0`PD^6<,(WE`#"@X__]_^L``%#C``"@
M$PD``!H0,)WE#SH#X@H*4^,!"5,3!```&@(0H.,$`*#A:OW_ZQ`/;^&@`J#A
M,""?Y2@PG^4"((_@`S"2YP`@D^6<,)WE`B`SX``PH.,````*`/[_ZZ#0C>(0
M@+WH7'0!`"`!``#\<P$`\$\MZ0%0H.'`(9_EP#&?Y0(@C^`#,)+G%-!-X@`P
MD^4,,(WE`#"@XP`PT>4`8*#A/0!3XP%0@0(%`*#AZ/W_ZP@0C>(`<*#A!@"@
MX?K^_^N`D9_E`$!0X@F0C^`1```*W_W_ZP``5^$F``"*`4!$X@$PU>0``%/C
M`3#DY?O__QI4(9_E2#&?Y0(@C^`#,)+G`""3Y0PPG>4"(#/@`#"@XT@```K1
M_?_K,#&?Y0.@F><`L)KE!#&;YP``4^,R```:'#&?Y0*`A.(#,(_@`""3Y0B!
MH.$``%+C+0``"@@0H.$+`*#A&?W_ZP``4.,``(KEXO__"@`@H.,`,)KE"$"-
MY0@P@^`$(`/E!C"@X0,`H.$!(-/D``!2XST`4A/Z__\:N#"?Y08`0.`#0)GG
M`G"'X@<`@.`(@)WE`)"4Y3#]_^L``%#C"`&)Y\S__PH`,)3E""&3YP$0UN0"
M,*#A``!1XST`41,`$,+E`2""XOC__QH](*#C`"##Y0$@U>0``%+C`2#CY?O_
M_QJ\___J`4"$XL?__^H!(*#C"`"@X0`@@^47_?_K`#!0X@0PC>6S__\*"Q"@
MX0@@2.(4_?_K!#"=Y0`PBN7*___J%-"-XO"/O>BX<P$`(`$``'!S`0!`<P$`
M'`$``)1T`0`00"WI,$"?Y3`PG^4$0(_@`S"4YP``D^5K_?_K(#"?Y2`0G^4#
M()3G'#"?Y0$0C^`#,(_@$$"]Z%W]_^K4<0$`&`$``#`!```U(0``-&```!-`
M+>E,,)_E3""?Y0,PC^`"0)/G``"4Y5?]_^OC___K``"4Y53]_^L`(*#C+#"?
MY00@C>4H$)_E*""?Y0,PC^``,(WE`B"/X`$0C^"]_/_K"-"-XA"`O>B$<0$`
M&`$``%PC``#E(```.`\``'!`+>DP(9_E,#&?Y0+:3>(8T$WB`B"/X`,PDN<"
M&HWB%!"!X@`PD^4`,('E`#"@X[7\_^L((9_E"&&?Y0(@C^``((WE`"&?Y0Q`
MC>(`,*#A!A"@X00`H.$"((_@F_S_ZP$P@.(&`%/A````FO``\.<!`'#C#```
M&@`PH./,$)_EN""?Y0$0C^`""HWB`B"1YQ0`@.(`$)+E`""0Y0$0,N``(*#C
M(```"B?]_^L!6HWB$%"%X@0`H.$!*J#C!1"@X=;\_^L`0%#BZO__N@$`A.*B
M_/_K`#!0XN;__PH%`%/A`@``*@0@@^`"`%7AWO__.@4`4^$"``":!""%X`(`
M4^'9__\Z!@!4X=?__\H$(*#A`P"@X040H.$"_?_K`""@XP`PH.$$(,#GT___
MZ@,`H.$"VHWB&-"-XG"`O>@0<0$`(`$``*8@```!$```?B```*!P`0"I___J
M\$\MZ?@AG^7X,9_E0MU-X@(@C^`TT$WB`$"@X>@!G^4#,)+G`5"@X4(=C>(`
M`(_@+!"!X@`PD^4`,('E`#"@XRG^_^LO$*#C`&"@X00`H.&*_/_K``!0XP\`
M``JL`9_E!!"@X0``C^#E_O_KH"&?Y9`QG^4"((_@0AV-X@,PDN<L$('B`""3
MY0`PD>4"(#/@`#"@XU8```K5_/_K!`"@X=#\_^L,`(WE!0"@X63\_^M@$9_E
M8)&?Y0$0C^"Z_/_K`'"@X52AG^54L9_E"9"/X`J@C^`+L(_@``!7X][__PH`
M(-?E``!2XPEPH`$``%;C"0``"@<0H.$&`*#A+_S_ZP``4.,$```:&!&?Y0$0
MC^"E_/_K`'"@X>[__^H'`*#AL/S_ZP#`H.,``(?@!Q!`X`$@<.4O`%+C$0``
M"@PPG>4!((/B`2""X`$*4N/"__^JL("-X@102.(',*#A"B"@X0$:H.,%`*#A
M!$"-Y0"PC>4`_/_K`0"`X@$*4.,"``":\`#PYP#`P.7G___J!0"@X1`0C>)R
M_/_K``!0XQ```!J0,!CE#SH#X@()4^,,```:`1"@XP4`H.'K^__K``!0XP<`
M`!I@`)_E!1"@X0``C^"+_O_K!0"@X1G\_^L`0*#AH?__ZD00G^4``*#C`1"/
MX,;__^H$`*#A0MV-XC30C>+PC[WHO&\!`"`!``!B'P``,Q\``%AO`0#L'@``
M>1X``*T?``#2'@``F!X``,L=``"X'0```#"@X0$@T^0``%+C'O\O`2\`4N,#
M`*`!^?__ZA!`+>D`0%#B`@``"@`PU.4``%/C`P``&MP`G^4``(_@$$"]Z/+[
M_^I:_/_K`0!`X@``A.```%3A`#"@X1L``"H`(-/E`0!`XB\`4N/X__\*`P!4
MX14``"H#(*#A`1!2Y"\`4>,/```:`3!#X@,`5.$#(*#A`P``*@`0TN4!,$/B
M+P!1X_C__PH$($+@`C""X@$*4^,6``"*`2""X@$*4N,,``":\`#PYP(PH.'G
M___J`P!4X>O__QH`,-3E+P!3XS@`GP4``(\`U/__"C``G^4``(_@T?__ZB@`
MG^4$$*#A``"/X`!`H.'E^__K!`"@X1"`O>@``*#C$("]Z-D<```Q'```AAP`
M`$!N`0`00"WIQ"&?Y<0QG^4"((_@*-!-X@,PDN<-(*#AM!&?Y0`PD^4D,(WE
M`#"@XP$0C^`*,('B*L"!X@+@H.$``)/E!!"3Y0@P@^(#`*[H#`!3X0X@H.'W
M__\:L##3X7@!G^6P,,[A``"/X&']_^ML`9_E;$&?Y0``C^!=_?_K9`&?Y01`
MC^```(_@6?W_ZU@!G^4``(_@5OW_ZU`!G^4``(_@4_W_ZT@!G^4``(_@4/W_
MZT`!G^4``(_@3?W_ZS@!G^4``(_@2OW_ZP0`H.%(_?_K*`&?Y0``C^!%_?_K
M(`&?Y0``C^!"_?_K&`&?Y0``C^`F_?_K`!!0X@$```H$`*#AZ/W_ZP`!G^4`
M`(_@'_W_ZP`04.("```*\`"?Y0``C^#@_?_KZ`"?Y0``C^`7_?_K`!!0XA$`
M``K8`)_E``"/X-C]_^O0$)_ET`"?Y0$0C^```(_@T_W_Z\0@G^5P,)_E`B"/
MX`,PDN<`()/E)#"=Y0(@,^``,*#C$@``"L7[_^N@`)_E``"/X`#]_^L`$%#B
ME`"?%0``CQ#H__\:C!"?Y0H@H.,!$(_@$0"-XD3[_^L``%#CXO__&G0`G^4;
M$(WB``"/X-W__^HHT(WB$("]Z&1L`0`@`0``R%H``.@;``#A&P``$QP``-D;
M``#6&P``T1L``-4;``!^&P``R1L``,D;``!;&P``NQL``+`;``"N&P``K1L`
M`/8:``"U&P``'1L``!!K`0!A&P``]1H``%(;``#)&@``$$`MZ4PPG^4#,(_@
M`#"3Y0$`<^,,```:/`"?Y0``C^#,_/_K``!0XP0```H``-#E,`!0XP``4!,!
M`*`3``"@`Q@PG^4#,(_@``"#Y1`PG^4#`)_G$("]Z'!K`0`U&@``-&L!`"AK
M`0`00"WI?OO_ZR/[_^L``%#C``"0%1"`O>CW0"WIF'"?Y0!`H.$'<(_@!P"@
MX:_\_^L`4%#B!!"@X0(```H`,-7E``!3XP0``!IP`)_E``"/X`S0C>+P0+WH
M:OW_ZO_Z_^L``%#C$@``&@0`H.%>^__K`&"@X04`H.%;^__K``"&X`(`@.+@
M^O_K`&"@X3`PG^4P$)_E!""@X0$0C^``4(WE`S"/X$?[_^L&$*#A!P"@X>;_
M_^H,T(WB\("]Z#\:```7&@``"!D``.D9``#P3RWI9":?Y60VG^6!W$WB)-!-
MX@(@C^!8QI_E`S"2YX$<C>(23HWB#,"/X``PD^4<,('E`#"@XW0P1.(04(SB
M7.!$XAP0@>(`8*#A!P"<Z0<`@^@/`+7H#P"NZ`,`E>AH,$3B*,",X@,`CN@'
M`)SH!P"#Z``&G^4`=I_E``"/X&?\_^L`4%#B!W"/X!0```H`,-7E``!3XQ$`
M``JJ___KW"6?Y<@UG^4"((_@@1R-X@,PDN<<$('B`""3Y0`PD>4"(#/@`#"@
MXP````H6^__K!0"@X8'<C>(DT(WB\$^]Z*7Z_^J2___K`%!0XFB`1`)F```*
M!0"@X0C[_^N``*#A`0"`XHWZ_^L`D*#A`("@X7"EG^4!4$7B"J"/X`$@]>4`
M`%+C7P``&ER`1.($4)CD``!5XPP```H%`*#A./S_ZP!04.+X__\*`##5Y0``
M4^/U__\*T/S_ZP``4./R__\*!0"@X83Z_^L`4*#A=*!$X@``5>,%```:!(":
MY```6.-5```*`##8Y0``4^-*```:!0"@X>'Z_^L`H*#A"0"@X=[Z_^L`H(K@
M`:N*X@2@BN(*`*#A8?K_ZP"`H.'(-)_ER!2?Y0,PC^``,(WEP#2?Y04@H.$#
M,(_@`1"/X`20C>7%^O_K!QV@XP@`H.&P^O_K`0!PXSH``!JJ^O_K`#"0Y1$`
M4^,V```*B"2?Y8@4G^4"`)?G`#"-Y0`@EN4(,*#A``"0Y0$0C^"&^O_K`%"@
MXV@DG^4X-)_E`B"/X($<C>(#,)+G'!"!X@`@D^4`,)'E`B`SX``PH..;__\:
M!0"@X8'<C>(DT(WB\(^]Z.S[_^L`,%#B!0``"@`PT^4``%/C`@``"CSZ_^L`
M4%#BF/__&@0`F.0``%#C\___&@!4G^4%4(_@DO__Z@@`H.$*$*#AD?K_ZP*`
MB.*7___J"`"@X77\_^L``%#CJO__"@@`H.$I^O_K`%"@X:3__^H(4*#AJO__
MZ@@`H.$0$(WB=OK_ZP"04.((```*F#.?Y:03G^4#`)?G`""6Y0@PH.$!$(_@
M``"0Y4OZ_^O#___J`#$4Y0\Z`^(!"5/C\O__&OA0%.6`^O_K``!5X>[__QH`
M,13E@SN@X:,[H.$'#5/CZ?__&@H`H.'Y^?_K`%"@X4@#G^4``(_@KOO_ZP`0
M4.)A```:`'"6Y0<`H.%H^O_K`P!0XP"@H.$:``":(!.?Y00`0.(!$(_@``"'
MX-;Y_^L``%#C$P``&@0`6N,#```*"J"'X`4P6N4O`%/C#0``&@1@EN4``%;C
M"@``"@8`H.%3^O_K`P!0XP8``)K4$I_E!`!`X@$0C^```(;@POG_ZP``4.,&
M<*`!M/[_ZP"@4.)R```:"A"@X0<`H.'>^?_K`&!0XFT```H"D*#C`##@XQ$@
MX.,`D(WE!'!$XJSY_^L&(*#C!Q"@X08`H.$.^O_K!#!4Y0``4^,P```:`S!4
MY4,`4^,M```:`C!4Y4$`4^,J```:`3!4Y4,`4^,G```:`##4Y4@`4^,D```:
M`3#4Y44`4^,A```:`##@XSD@X.,&`*#A`)"-Y9'Y_^LI(*#C!Q"@X08`H.'S
M^?_K"""@X00RG^4$$I_E`S"/X`0PC>7\,9_E`'"-Y0,PC^`!$(_@!0"@X0GZ
M_^L(`*#A^/G_Z^`!G^4%$*#A``"/X!/\_^L%`*#AE?[_ZTW__^H``);E#?W_
MZP!P4.*:__\:F/__Z@`PH.,`(*#C`#"-Y08`H.$`,*#C;OG_Z_P#`.L`D*#A
M`BF@XP<0H.$&`*#ASOG_ZP`@4.(=``#*!@"@X41@1.+#^?_K,'!$X@D0H.$&
M`*#A4P0`ZP>0H.%<L9_E"["/X`<`H.$+$*#A`2#6Y`&@BN+>^?_K%`!:XP)P
MA^+W__\:`#"@XP@P1.4P,9_E,!&?Y0,PC^`$,(WE*#&?Y0@@H.$`D(WE`S"/
MX`$0C^##___J!Q"@X0D`H.'H`P#KU___Z@01G^4$`9_E`1"/X```C^#6^__K
M0?G_Z_0PG^7T$)_E`S"/X`D`C>CL,)_E"""@X04`H.$#,(_@`1"/X+OY_^O8
M0)_EV&"?Y=APG^4$0(_@!F"/X`=PC^`'':#C!0"@X:#Y_^L!`'#CIO__&IKY
M_^L`,)#E$0!3XZ+__QHG^?_K`9")X@$"C>@$,*#A"""@X080H.$%`*#A"'"-
MY:/Y_^OL___J\&@!`"`!```<:@$`2A@``'QH`0!<:`$`EA@``/@7``#;%P``
M"A<````!``"=%P``S&8!``<7``#P%@``0A8``+\6``!T%@``6!8``)$5```:
M%```XA,``$84``!P%0``I10``"X3``#!$P``11,``"`5``!D%```WA(``,82
M``!:%```[!0``'-`+>DH,I_E*"*?Y0,PC^`"0)/G``"4Y7;Y_^L`4*#A``"4
MY7/Y_^MD,-7E93#`Y00"G^4``(_@N_K_ZP``4.,%```*`##0Y3$`4^,"```:
M`3#0Y0``4^,````*3OW_ZP``E.5C^?_KT!&?Y0,PH.,!(*#C`1"/X`WY_^L`
M4%#B$```"@``E.5:^?_K##"5Y:PAG^4`$)/E`B"/X`KY_^L,,)7E`#"3Y0@P
MD^4!!1/C!```"@``E.5.^?_K##"5Y0`0D^79^/_K``"4Y4GY_^MP$9_E`S"@
MXP$@H.,!$(_@\_C_ZP!04.(7```*6`&?Y0``C^",^O_K`"!0X@0@C>4&```*
M``"4Y3KY_^L,,)7E!""=Y0`0D^7K^/_K"@``ZO#[_^L`8%#B``"4Y2@```HP
M^?_K##"5Y08@H.$`$)/EX?C_ZP8`H.$>^?_K``"4Y2CY_^L`4*#A``"4Y27Y
M_^OH$)_E`2"@XP$0C^"+^/_KW""?Y0`0H.$"((_@!0"@X='X_^L``)3E&OG_
MZP`PH.-E,,#EO`"?Y;Q`G^4``(_@8?K_ZP1`C^```%#C"`"$Y0X``!H$`)3E
MTOW_ZP``4.,(`(3E"0``&I``G^4``(_@?OC_ZP?Y_^N$,)_E`S"/X`0@D^4,
M,)7E`""2Y<C__^IP0)_E!QV@XP1`C^`(`)3E[?C_ZP$@@.(1`%#C`0!2$P`P
MH.$$``":3`"?Y08`E.D``(_@`!"1Y6CX_^L(T(WB<("]Z`!B`0`8`0``U1$`
M`!L3``#Y$@``NA(``.<0```P$@``-1(``#(0``#\80$`YQ$``,1A`0"H80$`
MM!$``'!`+>D`0*#AA/S_ZWS\_^L`4*#A4OW_ZP``4.,``%03<("]"``PU.4`
M`%/C<("]"!P0G^4%`*#A`1"/X'KX_^L``%7A<("]&`0`H.%P0+WH7OK_ZAP0
M``#P3RWI-"N?Y30[G^4"((_@4]]-X@,PDN<$((WB`L"@X0`PD^5$,8WE`#"@
MXUS@@.(<,(#B!!"3Y#$?O^8#`%[A!!",Y/K__QI`P*#C`A"@X2#@D>4T,)'E
M!"""X@XP(^`(X)'E`!"1Y0XP(^`!,"/@XS^@X0'`7.(\,(+E\O__&L`ZG^4$
MD)WE$&"0Y=A`P.$#D(G@!2`DX(!`D.@&D(G@#B`"X`4@(N#GG8G@`I")X`@@
MG>5N$23@!Q`!X`,@@N`%((+@!!`AX&?!H.$"$('@#""=Y6Z!+.`)@`C@`R""
MX`0@@N`0H)WE;H$HX.D=@>`"@(C@:2$LX`$@`N`#H(K@X8V(X&ZABN!A$:#A
M%+"=Y0P@(N`*((+@::$AX`.PB^`(H`K@#,"+X&FA*N`8L)WEZ"V"X`R@BN!H
MP2'@`["+X`+`#.#BK8K@:9&+X&(AH.$<L)WE`<`LX`G`C.!HD2+@`["+X`J0
M">`!$(O@:)$IX""PG>7JS8S@`9")X&H1(N`#L(O@#!`!X.R=B>!H@8O@;,&@
MX22PG>4"$"'@"!"!X&J!+.`#L(O@"8`(X`(@B^!J@2C@*+"=Y>D=@>`"@(C@
M:2$LX`.PB^`!(`+@X8V(X&JAB^!A$:#A++"=Y0P@(N`*((+@::$AX`.PB^`(
MH`K@#,"+X&FA*N`PL)WEZ"V"X`R@BN!HP2'@`["+X`+`#.#BK8K@:9&+X&(A
MH.$TL)WE`<`LX`G`C.!HD2+@`["+X`J0">`!$(O@:)$IX#BPG>7JS8S@`9")
MX&H1(N`#L(O@#!`!X.R=B>!H@8O@;,&@X3RPG>4"$"'@"!"!X&J!+.`#L(O@
M"8`(X`(@B^!J@2C@0+"=Y>D=@>`"@(C@:2$LX`.PB^`!(`+@X8V(X&JAB^!A
M$:#A1+"=Y0P@(N`*((+@::$AX`.PB^`(H`K@#,"+X&FA*N!(L)WEZ"V"X`R@
MBN!HP2'@`["+X`+`#.#BK8K@:9&+X&(AH.%,L)WE`<`LX`G`C.!HD2+@`["+
MX`J0">`!$(O@:)$IX`&0B>!0$)WEZLV,X&JQ(N`,L`O@`S"!X&@Q@^`"L"O@
M5("=Y0.PB^`4.)_E[)V)X&P1H.$#@(C@6,"=Y0*`B.!J(2'@"2`BX`/`C.#I
MO8O@`H"(X&K!C.!I(2'@7*"=Y0L@(N`"P(S@`Z"*X&LAH.'KC8C@`:"*X&D1
M(N`($"'@`:"*X&`0G>7HS8S@`Q"!X&D1@>!HD2+@#)`IX`D0@>!DD)WE[*V*
MX`.0B>!LP:#A`I")X&@A+.`*("+@`I")X&@@G>7J'8'@`R""X&@A@N!J@2S@
M`8`HX`@@@N!L@)WEX9V)X`.`B.!A$:#A#("(X&K!(>`)P"S@#("(X'#`G>7I
M+8+@`\",X&K!C.!IH2'@`J`JX`K`C.!TH)WEXHV(X`.@BN!B(:#A`:"*X&D1
M(N`($"'@`:"*X'@0G>7HS8S@`Q"!X&D1@>!HD2+@#)`IX`D0@>!\D)WE[*V*
MX`.0B>!LP:#A`I")X&@A+.`*("+@`I")X(`@G>7J'8'@`R""X&@A@N!J@2S@
M`8`HX`@@@N"$@)WEX9V)X`.`B.!A$:#A#("(X&K!(>`)P"S@#("(X(C`G>7I
M+8+@`\",X&K!C.!IH2'@`J`JX`K`C.",H)WEXHV(X`.@BN!B(:#A`:"*X&D1
M(N`($"'@`:"*X)`0G>7HS8S@`Q"!X&D1@>!HD2+@#)`IX`D0@>"4D)WE[*V*
MX`.0B>!LP:#A`I")X&@A+.`*("+@`I")X)@@G>7J'8'@`R""X&@A@N!J@2S@
M`8`HX`@@@N"<@)WEX9V)X`.`B.!A$:#A#("(X&K!(>`)P"S@#("(X*#`G>7I
M+8+@`\",X&DQ(>#BC8C@`C`CX&(AH.%JP8S@::&"X0/`C.`(H`K@:3$"X*2P
MG>4#H(KAI#6?Y>C-C.`#L(O@`1"+X`&@BN!H$8+A:+$"X`P0`>`+$('AJ+"=
MY>RMBN`#L(O@;,&@X6F1B^`)$('@:)&,X6BQ#.`*D`G@"Y")X:RPG>7J'8'@
M`["+X`(@B^`"D(G@:B&,X6JQ#.`!(`+@"R""X;"PG>7AG8G@`["+X&$1H.%H
M@8O@""""X&J!@>%JL0'@"8`(X`N`B.&TL)WEZ2V"X`.PB^`,P(O@#("(X&G!
M@>%IL0'@`L`,X`O`C.&XL)WEXHV(X`.PB^!B(:#A:J&+X`K`C.!IH8+A:;$"
MX`B@"N`+H(KAO+"=Y>C-C.`#L(O@`1"+X`&@BN!H$8+A:+$"X`P0`>`+$('A
MP+"=Y>RMBN`#L(O@;,&@X6F1B^`)$('@:)&,X6BQ#.`*D`G@"Y")X<2PG>7J
M'8'@`["+X`(@B^`"D(G@:B&,X6JQ#.`!(`+@"R""X<BPG>7AG8G@`["+X&$1
MH.%H@8O@""""X&J!@>%JL0'@"8`(X`N`B.',L)WEZ2V"X`.PB^`,P(O@#("(
MX&G!@>%IL0'@`L`,X`O`C.'0L)WEXHV(X`.PB^!B(:#A:J&+X`K`C.!IH8+A
M:;$"X`B@"N`+H(KAU+"=Y>C-C.`#L(O@`1"+X`&@BN!H$8+A:+$"X`P0`>`+
M$('AV+"=Y>RMBN`#L(O@;,&@X6F1B^`)$('@:)&,X6BQ#.`*D`G@"Y")X=RP
MG>7J'8'@`["+X`(@B^`"D(G@:B&,X6JQ#.`!(`+@"R""X>"PG>7AG8G@`["+
MX&$1H.%H@8O@:K&!X0@@@N`)L`O@:H$!X`BPB^'D@)WEZ2V"X`.`B.`,P(C@
M:8&!X0RPB^`"@`C@:<$!X`R`B.'HP)WEXKV+X`/`C.!B(:#A:L&,X&FA@N$,
M@(C@"Z`*X&G!`N`,H(KA[,"=Y>N-B.`#P(S@`1",X&O!@N$!H(K@",`,X&L1
M`N`!P(SA\!"=Y>BMBN`#,('@:3&#X`/`C.#T$)WEP#*?Y6B!H.$#$('@`B"!
MX&L1*.`*$"'@`2""X/@0G>7JS8S@:I$HX`,0@>`,D"G@:Q&!X`D0@>#\D)WE
M["V"X`.0B>!LP:#A")")X&J!+.`"@"C@")")X`"!G>7B'8'@`X"(X&J!B.!B
MH2S@`:`JX`J`B.`$H9WEX9V)X`.@BN!A$:#A#*"*X&+!(>`)P"S@#*"*X`C!
MG>7IC8C@`\",X&+!C.!I(2'@""`BX.BMBN`"P(S@:"&@X0R!G>44L9WE`X"(
MX`&`B.!I$2+@"A`AX`&`B.`0$9WEZLV,X`,0@>!I$8'@:I$BX.R-B.`,D"G@
M`["+X&S!H.$"L(O@:B$LX`@@(N`"L(O@&"&=Y0D0@>#H'8'@:)$LX`,@@N`!
MD"G@:B&"X`D@@N`<D9WEX;V+X`.0B>!A$:#A#)")X&C!(>`+P"S@#)")X"#!
MG>4DH9WE`\",X.LM@N!HP8S@:X$AX.*=B>`"@"C@`Z"*X&(AH.$!H(K@:Q$B
MX`D0(>`!H(K@*!&=Y0C`C.#IS8S@:8$BX`,0@>`,@"C@:Q&!X`@0@>`L@9WE
M[*V*X`.`B.!LP:#A`H"(X&DA+.`*("+@`H"(X#`AG>7J'8'@`R""X&DA@N!J
MD2S@`9`IX`D@@N`TD9WEX8V(X`.0B>!A$:#A#,")X&J1(>`(D"G@"<",X#B1
MG>7H+8+@`Y")X&J1B>!HH2'@`J`JX`J0B>`\H9WEXLV,X`.@BN!B(:#A`1"*
MX&BA(N`,H"K@"A"!X$"AG>7LG8G@`S"*X`<P@^!L<2+@:#&#X`EP)^#I'8'@
M!S"#X.$]@^`"8(;@8""?Y0`P@.4!X([@0#"?Y6E!A.!L487@`B"/X`3@@.4(
M0(#E#%"`Y1!@@.4#,)+G`""3Y40QG>4"(#/@`#"@XP````H,]O_K4]^-XO"/
MO>@X7P$`(`$``)EY@EJAZ]ENW+P;C];!8LH\5`$`$$`MZ6``H..%]?_K*!"?
MY2@@G^4HP)_E*."?Y090@.@D()_E$""`Y0`@H.,4((#E&""`Y5P@@.40@+WH
M`2-%9XFKS>_^W+J8=E0R$/#ATL/P02WI`F"@X10PD.6"(:#A`C"3X!@@D"44
M,(#E`2""(A@@@"48,)#E`%"@X:8^@^`8,(#E7#"0Y1QP@.(``%/C&0``"D!`
M8^(&`%3A`P"'X`9`H*$!`%#A`P``*@0P@.`#`%'A````*O``\.<!`%#A!("!
MX`$``)H(`%#A^?__.@0@H.'$]?_K7#"5Y0,PA.!``%/C7#"%Y?"!O1@%`*#A
MZ_S_ZP@0H.$$8$;@7("%XC\`5N,.``#*!P!1X0(``)H&,(?@`P!1X>;__SH'
M`%'A`@``*@8P@>`#`%?AX?__.@8@H.$'`*#AJ_7_ZUQ@A>7P@;WH!P!1X0$`
M`)H(`%'AV/__.@$`5^%`,('B`0``F@,`5^'3__\Z`4"@X0<@H.$$$)3D`P!4
MX000@N3[__\:!0"@X<;\_^M`8$;B!!"@X=K__^KP02WI'("!XA0PD>488)'E
M`4"@X7\0X.,S?[_FHS&@X3\P`^(!((/B.`!2XP!0H.$#$,CG`@"(X``0H-,V
M;[_F."!BT@<``-H`$*#C0"!BX@7U_^L$`*#AK/S_ZS@@H.,`$*#C"`"@X?_T
M_^L$`*#A]&7$X:7\_^L#,-3E!`"@X0`PQ>6R,-3A`3#%Y0`PE.4C-*#A`C#%
MY0`PE.4#,,7E!S#4Y00PQ>6V,-3A!3#%Y00PE.4C-*#A!C#%Y00PE.4',,7E
M"S#4Y0@PQ>6Z,-3A"3#%Y0@PE.4C-*#A"C#%Y0@PE.4+,,7E#S#4Y0PPQ>6^
M,-3A#3#%Y0PPE.4C-*#A#C#%Y0PPE.4/,,7E$S#4Y1`PQ>6R,=3A$3#%Y1`P
ME.4C-*#A$C#%Y1`PE.43,,7E\$&]Z#7U_^H!0"WI`4"]Z![_+^$[````/@``
M``L````^````$````#X````E````/@```#,````^`````P```#X````&````
M/@```!0````^````#@```#X````-````/@```"0````^````$@```#X````G
M````/@````(````^````&````#X````)````/@````H````^````````````
M```N+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N
M86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`97AE`%!!4E]414U0`%!!4E]0
M4D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`
M4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"
M54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$
M25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%-94U1%30`E,#)X`"5S
M)7,E<R5S`'!A<BT`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`+G!A<@`E<R5S8V%C:&4M)7,E<P`E
M<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`&`!P97)L`#``4$%2.CI0
M86-K97(Z.E9%4E-)3TX`,2XP-30`56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`M90`M+0!54T52`%5315).
M04U%`%1%35!$25(`5$U0`"]T;7``979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D
M=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D
M=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N
M86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q
M6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*)%!!4E]-04=)0R`](")<
M;E!!4BYP;5QN(CL*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D
M("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H
M*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*
M<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL
M"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN
M*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-
M4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*
M;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?
M=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]4
M14U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["DU!1TE#.B![
M"FQO8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@
M7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D
M(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R
M92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1C
M:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US
M(%]&2#L*;7D@)&UA9VEC7W!O<R`]("1S:7IE("T@)'-I>F4@)2`D8VAU;FM?
M<VEZ93L@(R!.3U1%.B`D;6%G:6-?<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H
M=6YK7W-I>F4*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@
M)&UA9VEC7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@
M;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L
M("1005)?34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0[
M"GT*)&UA9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0II9B`H)&UA9VEC7W!O
M<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!
M4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*<F5A9"!?1D@L("1B=68L
M(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M('5N<&%C:R@B3B(L("1B
M=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES
M=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)
M3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;
M56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@
M)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E
M9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B
M=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@
M)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE
M(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE
M879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ
M2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L
M<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D
M14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1B
M87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE
M;F%M95QN(BD["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D(%]&2"P@
M)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T=7)N('5N
M;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@
M8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP
M<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D
M9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^
M>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5](#T@)&9I
M;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R;B`D9F@[
M"GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN9"!M;V1U
M;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@
M*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F
M:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]
M"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET
M96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F
M:6QE;F%M97T["GT*=6YL97-S("@D8G5F(&5Q(")02UPP,#-<,#`T(BD@>PIO
M=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP
M"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I
M970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T
M86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E
M<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF
M="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@
M0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG
M*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I
M('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@
M/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<[
M"GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS
M:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G
M3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q<5M#86XG="!O
M<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@97$@)U0G*2![
M"B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY
M("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S*"1F:"P@)TE/
M.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV
M92`B)'!A<B)=.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^
M(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@
M/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@
M)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE
M72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["F-L;W-E("1P:#L*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N
M)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS
M965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@*&1E9FEN960@)&1A=&%?
M<&]S*2!["G)E860@7T9(+"`D;&]A9&5R+"`D9&%T85]P;W,["GT@96QS92![
M"FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0IF;W)E86-H
M(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K
M97E](&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?
M7R(["FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R
M:6YT*"1L;V%D97(I.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T10
M04XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\
M(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$
M>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY
M("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@
M(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA
M;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]
M"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@
M;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H
M+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@
M:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD
M("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q
M6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@
M>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@
M/2!U;F1E9CL*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q
M<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)&9H/CL*
M8VQO<V4@)&9H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N
M=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL
M=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N
M9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ
M6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I.PIO=71S*'%Q6U=R:71T
M96X@87,@(B1N86UE(ETI.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M
M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q
M*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4@)&9H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S
M=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*"1005)?34%'24,I.PHD
M9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L
M90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O
M<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![
M(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES
M1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M
M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\*
M*#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N
M86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE
M*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T
M7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI
M('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A
M;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T
M<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE
M(ETI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]
M?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@
M)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D
M(5T["G-E96L@)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F
M+"`V.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@
M,CL*<F5A9"`D9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP
M9&ER("X]("(D<WES>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*;7D@
M)&1I9V5S="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X
M(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L
M("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@
M)"%=.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE
M>&1I9V5S=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D<WES>U]D96QI
M;7UC86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]=&5M
M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@
M7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\[
M"FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE
M("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*
M;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D:64@<7%;0V%N
M)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!
M345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2![
M"FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF
M("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P
M<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY
M("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]
M*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q
M("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O
M+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S
M>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R
M;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y
M<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D
M<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<
M12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P
M<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?
M24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6
M>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-
M4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.
M5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%
M0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G
M+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D
M<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@
M(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!
M3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@
M+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@
M)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*
M96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I
M<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF
M:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET
M96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X
M<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.
M0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID
M:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA
M;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D
M<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD
M.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z
M.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%
M4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,`7U]%
M3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("```#L````^````"P```#X`
M```0````/@```"4````^````,P```#X````#````/@````8````^````%```
M`#X````.````/@````T````^````)````#X````2````/@```"<````^````
M`@```#X````8````/@````D````^````"@```#X`````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````Y!8``%@6```!````*`,`
M``$````S`P``#P```'\$```,````#!````T```"@/0``&0```,R-`0`;````
M!````!H```#0C0$`'`````0```#U_O]O+`$```4```"D"```!@```!0"```*
M````G00```L````0````%0`````````#````Q(X!``(```#@`0``%````!$`
M```7````+`X``!$```!$#0``$@```.@````3````"````!@`````````^___
M;P$```CZ__]O$```````````````````````````````````````````````
M``````````#4C0$````````````8$```&!```!@0```8$```&!```!@0```8
M$```&!```!@0```8$```&!```!@0```8$```&!```!@0```8$```&!```!@0
M```8$```&!```!@0```8$```&!```!@0```8$```&!```!@0```8$```&!``
M`!@0```8$```&!```!@0```8$```&!```!@0```8$```&!```!@0```8$```
M&!```!@0```8$```&!```!@0```8$```&!```!@0```8$```&!```!@0```8
M$```&!```!@0```8$```&!```!@0```8$```&!```!@0``#\$@``````````
M``"@/0`````````````,$```````````````````````````````````````
M`````````````)`!`/_____M0```/3X````````>/P``%S\``.%````T/P``
MZ4````````#30```V$````````#R0```1T-#.B`H06QP:6YE(#$Q+C(N,5]G
M:70R,#(R,#(Q.2D@,3$N,BXQ(#(P,C(P,C$Y`$$R````865A8FD``2@````%
M-EI+``8'"`$)`0H"$@03`10!%0$7`Q@!&@(<`1X$(@%$`0`N<VAS=')T86(`
M+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN`"YR
M96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI
M;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S
M<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````````````````````````
M``````````````````````````````````L````!`````@```!0!```4`0``
M&````````````````0`````````3````]O__;P(````L`0``+`$``.@````#
M``````````0````$````'0````L````"````%`(``!0"``"0!@``!`````,`
M```$````$````"4````#`````@```*0(``"D"```G00``````````````0``
M```````M````"0````(```!$#0``1`T``.@````#``````````0````(````
M-@````D```!"````+`X``"P.``#@`0```P```!`````$````"````#\````!
M````!@````P0```,$```#```````````````!``````````Z`````0````8`
M```8$```&!```.0"``````````````0````$````10````$````&````_!(`
M`/P2``"D*@`````````````$`````````$L````!````!@```*`]``"@/0``
M#```````````````!`````````!1`````0````(```"L/0``K#T``%A`````
M``````````0`````````60````$````"````!'X```1^```$````````````
M```$`````````&,````.`````P```,R-`0#,C0``!```````````````!```
M``0```!O````#P````,```#0C0$`T(T```0```````````````0````$````
M>P````8````#````U(T!`-2-``#P````!``````````$````"````(0````!
M`````P```,2.`0#$C@``/`$`````````````!`````0```")`````0````,`
M````D`$``)```#P```````````````0`````````CP````@````#````/)`!
M`#R0```L$``````````````$`````````)0````!````,``````````\D```
M,0```````````````0````$```"=`````P``<```````````;9```#,`````
M``````````$``````````0````,``````````````*"0``"M````````````
*```!````````````
